=========
koine-nlp
=========

.. image:: https://travis-ci.org/nathans/koine-nlp.svg?branch=master
	   :target: https://travis-ci.org/nathans/koine-nlp
	      
.. image:: https://coveralls.io/repos/github/nathans/koine-nlp/badge.svg?branch=master
	   :target: https://coveralls.io/github/nathans/koine-nlp?branch=master


About
=====

A library for common NLP-related tasks for Koine
Greek.

The fullest use of the library comes in the normalize() function,
which combines all of the available methods to produce an end result
which is suitable for indexing.

View the `full documentation online <http://koine-nlp.nathan.smithfam.info/>`_.


Authors
=======

* © 2015, 2016 Nathan D. Smith <nathan@smithfam.info>

License
=======

koine-nlp is released under the terms of the The MIT License
(MIT). See COPYING for full license text.
